@@ -28,7 +28,8 @@ class BODYMOVIN_EXPORT BMStroke : public BMShape
 public:
     BMStroke() = default;
     explicit BMStroke(const BMStroke &other);
-    BMStroke(const QJsonObject &definition, BMBase *parent = nullptr);
+    BMStroke(const QJsonObject &definition, const QVersionNumber &version,
+             BMBase *parent = nullptr);
 
     BMBase *clone() const override;
 
@@ -48,6 +49,10 @@ protected:
     Qt::PenCapStyle m_capStyle;
     Qt::PenJoinStyle m_joinStyle;
     qreal m_miterLimit;
+    BMProperty<qreal> m_dashOffset;
+    BMProperty<qreal> m_dashLength;
+    BMProperty<qreal> m_dashGap;
+    bool m_isDashed = false;
 };
 
 QT_END_NAMESPACE
